summaryrefslogtreecommitdiffstats
path: root/quanta/dialogs/settings/parseroptions.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'quanta/dialogs/settings/parseroptions.cpp')
-rw-r--r--quanta/dialogs/settings/parseroptions.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/quanta/dialogs/settings/parseroptions.cpp b/quanta/dialogs/settings/parseroptions.cpp
index 24e3c6a6..c38e2875 100644
--- a/quanta/dialogs/settings/parseroptions.cpp
+++ b/quanta/dialogs/settings/parseroptions.cpp
@@ -22,11 +22,11 @@
#include <kconfig.h>
/*
* Constructs a ParserOptions which is a child of 'parent', with the
* name 'name' and widget flags set to 'f'
*/
-ParserOptions::ParserOptions( KConfig *a_config, TQWidget* parent, const char* name )
- : ParserOptionsUI( parent, name )
+ParserOptions::ParserOptions( KConfig *a_config, TQWidget* tqparent, const char* name )
+ : ParserOptionsUI( tqparent, name )
{
config = a_config;
config->setGroup("Parser options");
@@ -70,7 +70,7 @@ ParserOptions::ParserOptions( KConfig *a_config, TQWidget* parent, const char*
*/
ParserOptions::~ParserOptions()
{
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}
@@ -22,11 +22,11 @@
#include <kconfig.h>
/*
- * Constructs a ParserOptions which is a child of 'parent', with the
+ * Constructs a ParserOptions which is a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'
*/